reearth.ui.show(`
  <style>
    html,
    body {
      margin: 0;
      width: 350px;
      font-size: 14px;
    }
    button, p {
      margin: 0;
    }
    #wrapper {
      box-sizing: border-box;
      border-radius: 12px;
      padding: 12px;
      background: white;
    }
    h3{
      margin: 0 0 5px;
    }
    h4{
      margin: 5px 0;
    }
    .active{
      color: red;
    }
  </style>

  <div id="wrapper">
    <h3>Plugin Timeline Widget</h3>
    <p>My ID: <span id="myID"></span></p>

    <h4 id="tl1">Timeline 1</h4>
    <p>Start: <span id="tl1Start"></span></p>
    <p>Current: <span id="tl1Current"></span></p>
    <p>Stop: <span id="tl1Stop"></span></p>
    <button id="tl1Play">Play</button>
    <button id="tl1Pause">Pause</button>
    <button id="tl1Reset">Reset</button>

    <h4 id="tl2">Timeline 2</h4>
    <p>Start: <span id="tl2Start"></span></p>
    <p>Current: <span id="tl2Current"></span></p>
    <p>Stop: <span id="tl2Stop"></span></p>
    <button id="tl2Play">Play</button>
    <button id="tl2Pause">Pause</button>
    <button id="tl2Reset">Reset</button>

    <h4>Debug: Cesium widget</h4>
    <button id="showCesiumTimeline">Show</button>
    <button id="hideCesiumTimeline">Hide</button>
  </div>

  <script>
    let myId = null;
    let activeTimeline = null;
    let shouldUpdateCurrent = false;

    const tl1 = {
      start: '1970-01-01T00:00:00Z',
      stop: '1970-01-01T01:00:00Z',
      current: '1970-01-01T00:00:00Z'
    } 
    document.getElementById("tl1Start").innerHTML = new Date(tl1.start).toString();
    document.getElementById("tl1Stop").innerHTML = new Date(tl1.stop).toString();
    document.getElementById("tl1Current").innerHTML = new Date(tl1.current).toString();

    const tl2 = {
      start: '2020-01-01T00:00:00Z',
      stop: '2020-02-01T01:00:00Z',
      current: '2020-01-01T00:00:00Z'
    } 
    document.getElementById("tl2Start").innerHTML = new Date(tl2.start).toString();
    document.getElementById("tl2Stop").innerHTML = new Date(tl2.stop).toString();
    document.getElementById("tl2Current").innerHTML = new Date(tl2.current).toString();

    const setActiveTimeline = (tl) => {
      activeTimeline = tl;
      document.getElementById("tl1").classList.remove('active');
      document.getElementById("tl2").classList.remove('active');
      if(activeTimeline){
        document.getElementById(activeTimeline).classList.add('active');
      }
    }

    document.getElementById("tl1Play").addEventListener("click", (e) => {
      setActiveTimeline('tl1');
      shouldUpdateCurrent = true;
      parent.postMessage({ type: "play", timeline: tl1 }, "*");
    });
    document.getElementById("tl1Pause").addEventListener("click", (e) => {
      setActiveTimeline('tl1');
      shouldUpdateCurrent = false;
      parent.postMessage({ type: "pause" }, "*");
    });
    document.getElementById("tl1Reset").addEventListener("click", (e) => {
      setActiveTimeline('tl1');
      shouldUpdateCurrent = true;
      parent.postMessage({ type: "reset", timeline: tl1 }, "*");
    });

    document.getElementById("tl2Play").addEventListener("click", (e) => {
      setActiveTimeline('tl2');
      shouldUpdateCurrent = true;
      parent.postMessage({ type: "play", timeline: tl2 }, "*");
    });
    document.getElementById("tl2Pause").addEventListener("click", (e) => {
      setActiveTimeline('tl2');
      shouldUpdateCurrent = false;
      parent.postMessage({ type: "pause" }, "*");
    });
    document.getElementById("tl2Reset").addEventListener("click", (e) => {
      setActiveTimeline('tl2');
      shouldUpdateCurrent = true;
      parent.postMessage({ type: "reset", timeline: tl2 }, "*");
    });

    document.getElementById("showCesiumTimeline").addEventListener("click", (e) => {
      parent.postMessage({ type: "showCesiumTimeline" }, "*");
    });
    document.getElementById("hideCesiumTimeline").addEventListener("click", (e) => {
      parent.postMessage({ type: "hideCesiumTimeline" }, "*");
    });

    addEventListener("message", (e) => {
      if (e.source !== parent) return;
      if (e.data.type === 'getMyId') {
        myId = e.data.payload;
        document.getElementById("myID").innerHTML = e.data.payload;
      } else if (e.data.type === 'currentTime'){
        if(shouldUpdateCurrent && activeTimeline === 'tl1'){
          tl1.current = e.data.payload?.toString();
          document.getElementById("tl1Current").innerHTML = e.data.payload?.toString();
        }else if(shouldUpdateCurrent && activeTimeline === 'tl2'){
          tl2.current = e.data.payload?.toString();
          document.getElementById("tl2Current").innerHTML = e.data.payload?.toString();
        }
      } else if (e.data.type === 'onTimelineCommit'){
        if(e.data.payload?.id !== myId || e.data.payload?.source !== 'pluginAPI'){
          setActiveTimeline(null);
          shouldUpdateCurrent = false;
        }
      }
    });
  </script>
`);

reearth.on("message", (msg) => {
  if (msg.type === "play") {
    reearth.clock.setTime(msg.timeline);
    reearth.clock.play();
  } else if (msg.type === "pause") {
    reearth.clock.pause();
  } else if (msg.type === "reset") {
    reearth.clock.pause();
    reearth.clock.setTime({...msg.timeline, current: msg.timeline.start});
  }else if (msg.type === "showCesiumTimeline") {
    reearth.scene.overrideProperty({
      timeline: {
        visible: true
      }
    });
  } else if (msg.type === "hideCesiumTimeline") {
    reearth.scene.overrideProperty({
      timeline: {
        visible: false
      }
    });
  }
});

reearth.on("tick", ()=>{
  reearth.ui.postMessage({
    type: "currentTime",
    payload: reearth.clock.currentTime,
  });
})

reearth.on("timelinecommit", (committer) => {
  reearth.ui.postMessage({
    type: "onTimelineCommit",
    payload: committer,
  });
})

reearth.ui.postMessage({
  type: "getMyId",
  payload: reearth.widget?.id,
});